@@ -267,10 +267,16 @@ class DAAPClient(object):
     def connect(self, hostname, port = 3689, password = None):
         if self.socket != None:
             raise DAAPError("DAAPClient: already connected.")
+#        if ':' in hostname:
+#            raise DAAPError('cannot connect to ipv6 addresses')
+# if it's an ipv6 address
+        if ':' in hostname and hostname[0] != '[':
+            hostname = '['+hostname+']'
         self.hostname = hostname
         self.port     = port
         self.password = password
-        self.socket = httplib.HTTPConnection(hostname, port)
+#        self.socket = httplib.HTTPConnection(hostname, port)
+        self.socket = httplib.HTTPConnection(hostname+':'+str(port))
         self.getContentCodes() # practically required
         self.getInfo() # to determine the remote server version
 
@@ -400,7 +406,8 @@ class DAAPSession(object):
 
     def update(self):
         response = self.request("/update")
-        #response.printTree()
+	self.revision = response.getAtom('musr')
+#        return response
 
     def databases(self):
         response = self.request("/databases")
@@ -541,8 +548,12 @@ if __name__ == '__main__':
             # demo - save the first track to disk
             #print("Saving %s by %s to disk as 'track.mp3'"%(tracks[0].name, tracks[0].artist))
             #tracks[0].save("track.mp3")
-
-            tracks[0].atom.printTree()
+            if len(tracks) > 0 :
+                tracks[0].atom.printTree()
+            else:
+                print 'No Tracks'
+            session.update()
+            print session.revision
 
         finally:
             # this here, so we logout even if there's an error somewhere,
