@@ -1,4 +1,4 @@
-# exaile/exfalso - Tagger plugin for Exaile using the Ex Falso app
+# exaile/exfalso - Exaile plugin to use Ex Falso as tagger
 # Copyright (C) 2009-2010  Johannes Sasongko <sasongko@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,13 +18,13 @@ import os
 import gio, gtk
 import quodlibet as ql
 
-# Modify Quod Libet's print_ function to default to not print anything.
+# Modify Quod Libet's print_ function to default to not print anything (output=
+# None).
 qlprint = ql.print_
 def print_(string_, frm='utf-8', prefix='', output=None, log=None):
     qlprint(string_, frm, prefix, output, log)
 import __builtin__
-__builtin__.__dict__['print_'] = print_
-ql.print_ = print_
+__builtin__.__dict__['print_'] = ql.print_ = print_
 
 class ExFalsoController:
     def __init__(self, on_changed=None):
@@ -32,8 +32,16 @@ class ExFalsoController:
         from quodlibet.qltk.exfalsowindow import ExFalsoWindow
 
         config.init(const.CONFIG)
-        self.instance = instance = ql.init(gtk=False, backend='nullbe')
-        backend, library, player = instance
+
+        try:
+            self.instance = backend, library, player = ql.init(
+                gtk=False,  # Don't initialize GLib/GTK+ stuff.
+                backend='nullbe')
+            self.api_version = 1
+        except TypeError:
+            library = ql.init()
+            ql.init_backend('nullbe', library.librarian)
+            self.api_version = 2
 
         self.on_changed = on_changed
         if on_changed:
@@ -41,18 +49,23 @@ class ExFalsoController:
 
         self.window = window = ExFalsoWindow(library)
 
+        if self.api_version == 2:
+            from quodlibet import widgets
+            widgets.main = window
+            widgets.watcher = library.librarian
+
         # Ex Falso doesn't have any shortcut for the directory and file list
         # widgets, so we hack into them using multiple get_children calls.
         # Hierarchy:
         #   Window > HPaned > VBox > FileSelector (VPaned)
         #   - ScrolledWindow > DirectoryTree (TreeView)  # directory list
         #   - ScrolledWindow > AllTreeView (TreeView)  # file list
-        filesel = window.child.get_children()[0].get_children()[0]
+        filesel = window.get_child().get_children()[0].get_children()[0]
         children = filesel.get_children()
-        self.dirlist = dirlist = children[0].child
-        self.filelist = filelist = children[1].child
-        assert isinstance(dirlist, gtk.TreeView)
-        assert isinstance(filelist, gtk.TreeView)
+        self.dirlist = children[0].child
+        self.filelist = children[1].child
+        assert isinstance(self.dirlist, gtk.TreeView)
+        assert isinstance(self.filelist, gtk.TreeView)
 
     def _on_changed(self, library, items):
         # We can't directly use the items passed in because Ex Falso converts
@@ -84,18 +97,24 @@ class ExFalsoController:
         map(filesel.select_path, treepaths)
 
     def main(self):
+        """Runs the mainloop. Do not call if you have your own mainloop."""
         ql.main(self.window)
 
     def cleanup(self):
-        ql.quit(self.instance)
         from quodlibet import config, const
-        config.write(const.CONFIG)
+        if self.api_version == 1:
+            ql.quit(self.instance)
+            config.write(const.CONFIG)
+        elif self.api_version == 2:
+            from quodlibet.util import copool
+            copool.remove_all()
+            config.save(const.CONFIG)
         config.quit()
 
 import xl.event, xl.trax
 from xlgui import guiutil
 
-class ExFalsoTagger:
+class ExFalsoPlugin:
     def __init__(self, exaile):
         self.exaile = exaile
         self.exfalso = None
@@ -109,7 +128,7 @@ class ExFalsoTagger:
             ef = self.exfalso = ExFalsoController(self.on_changed)
             ef.window.connect('destroy', self.destroy)
         ef.window.present()
-        ef.select(track.local_file_name() for track in tracks)
+        ef.select(track.get_local_path() for track in tracks)
     def on_changed(self, paths):
         get_track = self.exaile.collection.get_track_by_loc
         for path in paths:
@@ -120,18 +139,14 @@ class ExFalsoTagger:
 
 PLUGIN = None
 
-# Hook to replace the Properties dialog opened from Collection panel or playlist
-# context menu.
-from xlgui.playlist import Playlist
-from xlgui.panel.collection import CollectionPanel
-xl_playlist_properties = Playlist.properties_dialog
-xl_panel_properties = CollectionPanel.properties_dialog
-def properties_dialog(self):
-    tracks = self.get_selected_tracks()
-    if len(tracks) == 0:
-        return False
-    PLUGIN.run(tracks)
-    return True
+# Hook to replace Exaile's original Properties dialog
+from xlgui import properties as xlprops
+xl_properties_dialog = xlprops.TrackPropertiesDialog
+def properties_dialog(parent, tracks, current_position=0, with_extras=False):
+    if with_extras:
+        PLUGIN.run((tracks[current_position],))
+    else:
+        PLUGIN.run(tracks)
 
 def enable(exaile):
     if exaile.loading:
@@ -142,16 +157,14 @@ def enable(exaile):
 @guiutil.idle_add()
 def _enable(event, exaile, nothing):
     global PLUGIN
-    PLUGIN = ExFalsoTagger(exaile)
-    Playlist.properties_dialog = properties_dialog
-    CollectionPanel.properties_dialog = properties_dialog
+    PLUGIN = ExFalsoPlugin(exaile)
+    xlprops.TrackPropertiesDialog = properties_dialog
 
 def disable(exaile):
     global PLUGIN
     PLUGIN.destroy()
     PLUGIN = None
-    Playlist.properties_dialog = xl_playlist_properties
-    CollectionPanel.properties_dialog = xl_panel_properties
+    xlprops.TrackPropertiesDialog = xl_properties_dialog
 
 if __name__ == "__main__":
     ef = ExFalsoController()
