@@ -1,5 +1,5 @@
 # karaoke - Removes voice from Exaile's audio output
-# Copyright (C) 2009  Johannes Sasongko <sasongko@gmail.com>
+# Copyright (C) 2009-2010  Johannes Sasongko <sasongko@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@ from xl.player.pipe import ElementBin
 class Karaoke(ElementBin):
     index = 50
     name = 'karaoke'
-    def __init__(self):
-        ElementBin.__init__(self, name=self.name)
+    def __init__(self, player):
+        ElementBin.__init__(self, player, name=self.name)
         self.elements[50] = gst.element_factory_make('audiokaraoke')
         self.setup_elements()
 
