@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 import os, sys
 
 # - good = works
@@ -7,7 +5,7 @@ import os, sys
 #   - extra = not very useful
 # - bad = doesn't work
 
-EXTRA = []
+EXTRA = ['helloworld']
 BAD = ['shoutcast']
 
 def scan():
