@@ -18,10 +18,9 @@
 import moodbarprefs
 import cgi, gtk, glib, os, os.path, subprocess, colorsys
 import inspect
-from xl import event, xdg, settings
+from xl import common, event, player, settings, xdg
 from xl.nls import gettext as _
 from xlgui.preferences import widgets
-from xl import common
 import moodbarprefs
 
 import logging
@@ -80,11 +79,11 @@ class ExModbar(object):
     #Setup-------------------------------------------------------------------
 
     def changeBarToMod(self):
-         place=self.pr.bar.get_parent()
+         place=self.pr.get_parent()
          self.mod = gtk.DrawingArea()
          self.mod.pangolayout = self.mod.create_pango_layout("")
          self.mod.set_size_request(-1, 24)
-         place.remove(self.pr.bar)
+         place.remove(self.pr)
          place.add(self.mod)
          self.mod.realize()
          self.mod.show()
@@ -93,7 +92,7 @@ class ExModbar(object):
          if hasattr(self, 'mod'):
              place=self.mod.get_parent()
              place.remove(self.mod)
-             place.add(self.pr.bar)
+             place.add(self.pr)
              self.mod.destroy()
 
     def setupUi(self):
@@ -108,10 +107,10 @@ class ExModbar(object):
               self.mod.connect("button-press-event", self.modSeekBegin)
               self.mod.connect("button-release-event", self.modSeekEnd)
               self.mod.connect("motion-notify-event", self.modSeekMotionNotify)
-              self.brush = self.mod.window.new_gc()
+              self.brush = self.mod.props.window.new_gc()
 
 
-              track = self.exaile.player.current
+              track = player.PLAYER.current
 
               self.lookformod(track)
 
@@ -131,7 +130,7 @@ class ExModbar(object):
          modLoc=self.moodsDir+'/'+ self.playingTrack.replace('/','-')+".mood"
          modLoc=modLoc.replace("'",'')
          needGen=False
-         self.curpos=self.exaile.player.get_progress()
+         self.curpos=player.PLAYER.get_progress()
          if os.access(modLoc, 0):
              self.modwidth=0
              if not self.readMod(modLoc):
@@ -140,7 +139,7 @@ class ExModbar(object):
          else: needGen=True
          if needGen:
              self.pid = subprocess.Popen(['/usr/bin/moodbar',
-                 track.local_file_name(), '-o', modLoc])
+                 track.get_local_path(), '-o', modLoc])
          self.haveMod=not needGen
 
          if self.modTimer: glib.source_remove(self.modTimer)
@@ -171,7 +170,7 @@ class ExModbar(object):
          self.modTimer = glib.timeout_add_seconds(1, self.updateMod)
 
     def updateplayerpos(self):
-         if self.modTimer: self.curpos=self.exaile.player.get_progress()
+         if self.modTimer: self.curpos=player.PLAYER.get_progress()
          self.mod.queue_draw_area(0, 0, self.get_size(), 24)
 
 
@@ -341,7 +340,7 @@ class ExModbar(object):
              0x0000,
              0x0000
          )
-         track = self.exaile.player.current
+         track = player.PLAYER.current
          if self.theme:
                 flatcolor1r,flatcolor1g,flatcolor1b=colorsys.yiq_to_rgb(0.5,self.ivalue,self.qvalue)
                 flatcolor2r,flatcolor2g,flatcolor2b=colorsys.yiq_to_rgb(0.5*darkmulti,self.ivalue,self.qvalue)
@@ -360,7 +359,7 @@ class ExModbar(object):
                  not self.cursor==self.cursor_old):
                     self.buff=self.genBuff()
             if (self.haveMod):
-                 this.window.draw_drawable(gc,self.pixmap, 0, 0, 0, 0, self.modwidth, 24)
+                 this.props.window.draw_drawable(gc,self.pixmap, 0, 0, 0, 0, self.modwidth, 24)
 
             else:
               if not self.defaultstyle:
@@ -370,7 +369,7 @@ class ExModbar(object):
                        int(flatcolor1g*0xFFFF*i/5+greenf*((5-float(i))/5)),
                        int(flatcolor1b*0xFFFF*i/5+bluef*((5-float(i))/5))
                    )
-                   this.window.draw_rectangle(gc, True, 0, 0+i,
+                   this.props.window.draw_rectangle(gc, True, 0, 0+i,
                            self.modwidth, 24-i*2)
 
               if self.modTimer and track.is_local():
@@ -379,7 +378,7 @@ class ExModbar(object):
                        int(flatcolor2g*0xFFFF),
                        int(flatcolor2b*0xFFFF)
                    )
-                   this.window.draw_rectangle(gc, True,
+                   this.props.window.draw_rectangle(gc, True,
                              (self.modwidth/10)*(self.uptime%10),
                              5, self.modwidth/10, 14)
               if self.defaultstyle:
@@ -388,7 +387,7 @@ class ExModbar(object):
                        int(flatcolor1g*0xFFFF),
                        int(flatcolor1b*0xFFFF)
                    )
-                   this.window.draw_rectangle(gc, True,
+                   this.props.window.draw_rectangle(gc, True,
                            0,12, self.modwidth, 2)
 
          except:
@@ -398,7 +397,7 @@ class ExModbar(object):
                   0x0000,
                   0x0000
               )
-              this.window.draw_rectangle(gc, True, 0, 0+i,
+              this.props.window.draw_rectangle(gc, True, 0, 0+i,
                      self.modwidth, 24-i*2)
 
             #if track and track.is_local():
@@ -406,7 +405,7 @@ class ExModbar(object):
 
             return False
 
-         track = self.exaile.player.current
+         track = player.PLAYER.current
          if not track or not (track.is_local() or \
                  track.get_tag_raw('__length')): return
 
@@ -420,7 +419,7 @@ class ExModbar(object):
                               int(flatcolor2g*0xFFFF*i/5+int(greenf*((5-float(i))/5))),
                               int(flatcolor2b*0xFFFF*i/5+int(bluef*((5-float(i))/5)))
                           )
-                          this.window.draw_rectangle(gc, True, 0, 0+i,
+                          this.props.window.draw_rectangle(gc, True, 0, 0+i,
                                  int(self.curpos*self.modwidth), 24-i*2)
                    else:
                       gc.foreground = this.get_colormap().alloc_color(
@@ -428,16 +427,16 @@ class ExModbar(object):
                           int(flatcolor2g*0xFFFF),
                           int(flatcolor2b*0xFFFF)
                       )
-                      this.window.draw_rectangle(gc, True,
+                      this.props.window.draw_rectangle(gc, True,
                            0,12, int(self.curpos*self.modwidth), 2)
                 else:
-                    this.window.draw_drawable(gc,self.pixmap2, 0, 0, 0, 0, int(self.curpos*self.modwidth), 24)
+                    this.props.window.draw_drawable(gc,self.pixmap2, 0, 0, 0, 0, int(self.curpos*self.modwidth), 24)
 
 
             else:
                 gc.foreground  = self.bgcolor;
                 gc.line_width=2
-                this.window.draw_arc(gc, True, int(self.curpos*self.modwidth)-15,
+                this.props.window.draw_arc(gc, True, int(self.curpos*self.modwidth)-15,
                         -5, 30, 30,  60*64, 60*64)
                 gc.foreground = this.get_colormap().alloc_color(
                     0x0000,
@@ -445,13 +444,13 @@ class ExModbar(object):
                     0x0000
                 )
 
-                this.window.draw_line(gc, int(self.curpos*self.modwidth), 10,
+                this.props.window.draw_line(gc, int(self.curpos*self.modwidth), 10,
                                       int(self.curpos*self.modwidth)-10, -5)
-                this.window.draw_line(gc, int(self.curpos*self.modwidth), 10,
+                this.props.window.draw_line(gc, int(self.curpos*self.modwidth), 10,
                                       int(self.curpos*self.modwidth)+10, -5)
 
-            length = self.exaile.player.current.get_tag_raw('__length')
-            seconds = self.exaile.player.get_time()
+            length = player.PLAYER.current.get_tag_raw('__length')
+            seconds = player.PLAYER.get_time()
             remaining_seconds = length - seconds
             text = ("%d:%02d / %d:%02d" %
                 ( seconds // 60, seconds % 60, remaining_seconds // 60,
@@ -463,13 +462,13 @@ class ExModbar(object):
             )
             this.pangolayout.set_text(text)
 
-            this.window.draw_layout(gc, int(self.modwidth/2)-35,
+            this.props.window.draw_layout(gc, int(self.modwidth/2)-35,
                      4, this.pangolayout)
-            this.window.draw_layout(gc, int(self.modwidth/2)-37,
+            this.props.window.draw_layout(gc, int(self.modwidth/2)-37,
                      2, this.pangolayout)
-            this.window.draw_layout(gc, int(self.modwidth/2)-35,
+            this.props.window.draw_layout(gc, int(self.modwidth/2)-35,
                      2, this.pangolayout)
-            this.window.draw_layout(gc, int(self.modwidth/2)-37,
+            this.props.window.draw_layout(gc, int(self.modwidth/2)-37,
                      4, this.pangolayout)
             gc.foreground = this.get_colormap().alloc_color(
                 0xFFFF,
@@ -477,7 +476,7 @@ class ExModbar(object):
                 0xFFFF
             )
 
-            this.window.draw_layout(gc, int(self.modwidth/2)-36,
+            this.props.window.draw_layout(gc, int(self.modwidth/2)-36,
                      3, this.pangolayout)
 
 
@@ -488,9 +487,8 @@ class ExModbar(object):
 
 
     def modSeekEnd(self,this,event):
-        global exaile1
         self.seeking = False
-        track = self.exaile.player.current
+        track = player.PLAYER.current
         if not track or not (track.is_local() or \
                 track.get_tag_raw('__length')): return
 
@@ -506,11 +504,11 @@ class ExModbar(object):
         #redrawMod(self)
 
         seconds = float(value * length)
-        self.exaile.player.seek(seconds)
+        player.PLAYER.seek(seconds)
 
     def modSeekMotionNotify(self,this,  event):
         if self.seeking:
-            track = self.exaile.player.current
+            track = player.PLAYER.current
             if not track or not (track.is_local() or \
                     track.get_tag_raw('__length')): return
 
@@ -547,17 +545,16 @@ def enable(exaile):
 
 def _enable(eventname, exaile, nothing):
     global ExaileModbar
-    track = ExaileModbar.exaile.player.current
     ExaileModbar.readMod('')
     ExaileModbar.setupUi()
-    event.add_callback(ExaileModbar.play_start, 'playback_track_start')
-    event.add_callback(ExaileModbar.play_end, 'playback_player_end')
+    event.add_callback(ExaileModbar.play_start, 'playback_track_start', player.PLAYER)
+    event.add_callback(ExaileModbar.play_end, 'playback_player_end', player.PLAYER)
 
 def disable(exaile):
     global ExaileModbar
     ExaileModbar.changeModToBar()
-    event.remove_callback(ExaileModbar.play_start, 'playback_track_start')
-    event.remove_callback(ExaileModbar.play_end, 'playback_player_end')
+    event.remove_callback(ExaileModbar.play_start, 'playback_track_start', player.PLAYER)
+    event.remove_callback(ExaileModbar.play_end, 'playback_player_end', player.PLAYER)
     ExaileModbar.destroy()
     ExaileModbar = None
 
