@@ -1,5 +1,5 @@
-# screensaverpause - pauses/resumes Exaile playback on screensaver start/stop
-# Copyright (C) 2009-2010  Johannes Sasongko <sasongko@gmail.com>
+# screensaverpause - pauses Exaile playback on screensaver activation
+# Copyright (C) 2009-2011  Johannes Sasongko <sasongko@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,10 +13,20 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+#
+# The developers of the Exaile media player hereby grant permission
+# for non-GPL compatible GStreamer and Exaile plugins to be used and
+# distributed together with GStreamer and Exaile. This permission is
+# above and beyond the permissions granted by the GPL license by which
+# Exaile is covered. If you modify this code, you may extend this
+# exception to your version of the code, but you are not obligated to
+# do so. If you do not wish to do so, delete this exception statement
+# from your version.
 
 
 import dbus, gtk
-from xl import event
+from xl import event, player, settings
 
 SERVICES = [
     dict( # GNOME
@@ -31,35 +41,33 @@ SERVICES = [
     ),
 ]
 
+import prefs
+def get_preferences_pane():
+	return prefs
+
 matches = set()
 bus = None
-exaile = None
 was_playing = None
 
-def active_changed(new_value):
-    if new_value:
-        global was_playing
-        was_playing = exaile.player.pause()
-    elif was_playing:
-        exaile.player.unpause()
+def screensaver_active_changed(is_active):
+    global was_playing
+    if is_active:
+        was_playing = player.PLAYER.is_playing()
+        player.PLAYER.pause()
+    elif was_playing and settings.get_option("screensaverpause/unpause", 0):
+        player.PLAYER.unpause()
 
-def enable(exaile_):
-    global exaile
-    exaile = exaile_
-    if exaile_.loading:
+def enable(exaile):
+    if exaile.loading:
         event.add_callback(_enable, 'exaile_loaded')
     else:
         _enable()
 
 def _enable(*a):
     global bus
-    try:
-        bus = dbus.SessionBus()
-    except dbus.DBusException:
-        # TODO: log
-        return
+    bus = dbus.SessionBus()
     for service in SERVICES:
-        matches.add(bus.add_signal_receiver(active_changed,
+        matches.add(bus.add_signal_receiver(screensaver_active_changed,
             signal_name='ActiveChanged', **service))
 
 def disable(exaile):
@@ -94,7 +102,7 @@ def test():
     def active_changed(new_value):
         if not new_value:
             mainloop.quit()
-    interface.connect_to_signal('ActiveChanged', active_changed)
+    interface.connect_to_signal('ActiveChanged', screensaver_active_changed)
 
     # For some reason Lock never returns.
     interface.Lock(ignore_reply=True)
