@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -160,8 +160,8 @@ class Track(object):
         # second TrackDB is consequently ignored. Thus if at all
         # possible, Tracks should NOT be persisted in more than one
         # TrackDB at a time.
+        unpickles = None
         if uri is None:
-            unpickles = None
             if len(args) > 2:
                 unpickles = args[2]
             else:
@@ -174,6 +174,24 @@ class Track(object):
             try:
                 tr = cls.__tracksdict[uri]
                 tr._init = False
+                
+                # if the track *does* happen to be pickled in more than one
+                # place, then we need to preserve any internal tags that aren't
+                # persisted to disk. 
+                #
+                # See https://bugs.launchpad.net/exaile/+bug/1054637
+                if unpickles is None:
+                    if len(args) > 2:
+                        unpickles = args[2]
+                    else:
+                        unpickles = kwargs.get("_unpickles")
+                
+                if unpickles is not None:
+                    for tag, values in unpickles.iteritems():
+                        tags = tr.list_tags()
+                        if tag.startswith('__') and tag not in tags:
+                            tr.set_tag_raw(tag, values)
+                
             except KeyError:
                 tr = object.__new__(cls)
                 cls.__tracksdict[uri] = tr
@@ -313,8 +331,9 @@ class Track(object):
             # error writing to the file, probably
             logger.warning( "Could not write tags to file: %s" % e )
             return False
-        except Exception:
+        except Exception, e:
             common.log_exception(logger)
+            logger.warning( "Unknown exception: Could not write tags to file: %s" % e )
             return False
 
     def read_tags(self):
@@ -742,6 +761,8 @@ class Track(object):
         """
             Sets the current track rating from an integer, on the
             scale determined by the ``rating/maximum`` setting.
+            
+            Returns the scaled rating
         """
         rating = float(rating)
         maximum = float(settings.get_option("rating/maximum", 5))
@@ -749,6 +770,7 @@ class Track(object):
         rating = max(0, rating)
         rating = float(rating * 100.0 / maximum)
         self.set_tag_raw('__rating', rating)
+        return rating
 
     ### Special functions for wrangling tag values ###
 
