@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -166,13 +166,15 @@ class TrackDB(object):
             raise AttributeError(
                     _("You did not specify a location to load the db from"))
 
+        logger.debug("Loading %s DB from %s." % (self.name, location))
+                    
         try:
             try:
-                pdata = shelve.open(self.location, flag='c',
+                pdata = shelve.open(location, flag='c',
                         protocol=common.PICKLE_PROTOCOL)
             except ImportError:
                 import bsddb3 # ArchLinux disabled bsddb in python2, so we have to use the external module
-                _db = bsddb3.hashopen(self.location, 'c')
+                _db = bsddb3.hashopen(location, 'c')
                 pdata = shelve.Shelf(_db, protocol=common.PICKLE_PROTOCOL)
             if pdata.has_key("_dbversion"):
                 if int(pdata['_dbversion']) > int(self._dbversion):
@@ -181,8 +183,8 @@ class TrackDB(object):
                 elif pdata['_dbversion'] < self._dbversion:
                     logger.info("Upgrading DB format....")
                     import shutil
-                    shutil.copyfile(self.location,
-                            self.location + "-%s.bak"%pdata['_dbversion'])
+                    shutil.copyfile(location,
+                            location + "-%s.bak"%pdata['_dbversion'])
                     import xl.migrations.database as dbmig
                     dbmig.handle_migration(self, pdata, pdata['_dbversion'],
                             self._dbversion)
@@ -215,7 +217,9 @@ class TrackDB(object):
                 else:
                     setattr(self, attr, pdata[attr])
             except Exception:
-                pass #FIXME
+                # FIXME: Do something about this
+                logger.warn("Exception occurred while loading %s" % location)
+                common.log_exception(log=logger)
 
         pdata.close()
 
@@ -249,15 +253,15 @@ class TrackDB(object):
             return
         self._saving = True
 
-        logger.debug("Saving %s DB to %s." % (self.name, self.location))
+        logger.debug("Saving %s DB to %s." % (self.name, location))
 
         try:
             try:
-                pdata = shelve.open(self.location, flag='c',
+                pdata = shelve.open(location, flag='c',
                         protocol=common.PICKLE_PROTOCOL)
             except ImportError:
                 import bsddb3
-                _db = bsddb3.hashopen(self.location, 'c')
+                _db = bsddb3.hashopen(location, 'c')
                 pdata = shelve.Shelf(_db, protocol=common.PICKLE_PROTOCOL)
             if pdata.get('_dbversion', self._dbversion) > self._dbversion:
                 raise common.VersionError, \
