@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -27,8 +27,8 @@
 import xdg
 
 major = "3.3"
-minor = "0"
-extra = "-dev"
+minor = "2"
+extra = ""
 
 def get_latest_bzr_revno(directory):
     """
