@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -87,6 +87,9 @@ class FilesContextMenu(menu.ProviderMenu):
         def get_selected_tracks(name, parent):
             return parent.tree.get_selected_tracks() or []
         context['selected-tracks'] = get_selected_tracks
+        context['selection-count'] = lambda name, parent: \
+            parent.tree.get_selection_count()
+        
         return context
 
 class FilesPanel(panel.Panel):
@@ -430,7 +433,13 @@ class FilesPanel(panel.Panel):
                 model.append((f, self.directory, name, ''))
             for sortname, name, f in subfiles:
                 size = f.query_info('standard::size').get_size() // 1024
-                size = locale.format_string(_("%d KB"), size, True)
+                
+                # locale.format_string does not support unicode objects
+                # correctly, so we call it with an str and convert the 
+                # locale-dependent output to unicode.
+                size = locale.format_string('%d', size, True)
+                size = _('%s KB') % unicode(size, locale.getpreferredencoding())
+                
                 model.append((f, self.track, name, size))
 
             if cursor:
@@ -478,6 +487,14 @@ class FilesDragTreeView(DragTreeView):
     """
         Custom DragTreeView to retrieve data from files
     """
+    def get_selection_count(self):
+        '''
+            Returns the number of items currently selected in the
+            playlist. Prefer this to len(get_selected_tracks()) et al
+            if you will discard the actual track list
+        '''
+        return self.get_selection().count_selected_rows()
+    
     def get_selected_tracks(self):
         """
             Returns the currently selected tracks
