@@ -403,6 +403,17 @@ class TrackPropertiesDialog(gobject.GObject):
                 modified.append((n, trackdata))
 
         if modified:
+            if len(modified) != 1:
+                dialog = gtk.MessageDialog(None,
+                        gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION,
+                        gtk.BUTTONS_YES_NO,
+                        _("Are you sure you want to apply changes to %d tracks?") % len(modified))
+                response = dialog.run()
+                dialog.destroy()
+                
+                if response != gtk.RESPONSE_YES:
+                    return
+                    
             self._tags_write(modified)
 
             del self.trackdata
@@ -532,7 +543,7 @@ class TrackPropertiesDialog(gobject.GObject):
                 for trackdata in self.trackdata:
                     try:
                         all_vals.append(trackdata[tag][multi_id])
-                    except KeyError:
+                    except (KeyError, IndexError):
                         all_vals.append('')
 
                 row.field.set_value(val(), all_vals, doupdate=False)
@@ -594,7 +605,7 @@ class TagRow(object):
         for track in parent.trackdata:
             try:
                 all_vals.append(track[tag_name][multi_id])
-            except KeyError:
+            except (KeyError, IndexError):
                 all_vals.append(None)
 
         self.field.set_value(value, all_vals)
@@ -861,13 +872,18 @@ class TagDblNumField(gtk.HBox):
         if all_val != None:
             all_vals = []
             for v in all_val:
-                all_vals.append(v.split('/'))
+                if v is not None:
+                    if len(v.split('/')) < 2:
+                        v += '/'
+                    all_vals.append(v.split('/'))
+                else:
+                    all_vals.append(None)
 
             # Set the value of the all button
             flags = [True, True]
             for i in range(2):
                 for v in all_vals:
-                    if vals[i] != v[i]:
+                    if v is None or vals[i] != v[i]:
                         flags[i] = False
 
                 if self.all_button[i] != None:
@@ -914,6 +930,7 @@ class TagImageField(gtk.HBox):
             'image/png': {
                 'title': _('PNG image'),
                 'type': 'png',
+                'options': {}
             },
             'image/': {
                 'title': _('Image'),
@@ -978,10 +995,22 @@ class TagImageField(gtk.HBox):
                 else:
                     self.batch_update = True
                     self.set_pixbuf(loader.get_pixbuf(), val.mime)
-                    self.type_selection.set_active(val.type)
-                    self.type_selection.set_sensitive(True)
-                    self.description_entry.set_text(val.desc)
-                    self.description_entry.set_sensitive(True)
+                    
+                    # some file types do not support multiple cover types
+                    if val.type is not None:
+                        self.type_selection.set_active(val.type)
+                        self.type_selection.set_sensitive(True)
+                    else:
+                        self.type_selection.set_active(-1)
+                        self.type_selection.set_sensitive(False)
+                        
+                    if val.desc is not None:
+                        self.description_entry.set_text(val.desc)
+                        self.description_entry.set_sensitive(True)
+                    else:
+                        self.description_entry.set_text('')
+                        self.description_entry.set_sensitive(False)
+                    
                     self.batch_update = False
             else:
                 self.batch_update = True
