@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -900,9 +900,9 @@ class PlaylistExportDialog(FileOperationDialog):
             Displays simple dialogs on messages
         """
         if message_type == gtk.MESSAGE_INFO:
-            info(None, message)
+            info(None, markup=message)
         elif message_type == gtk.MESSAGE_ERROR:
-            error(None, message)
+            error(None, markup=message)
 
     def on_response(self, dialog, response):
         """
