@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -181,7 +181,7 @@ class RandomizeMenuItem(menu.MenuItem):
         """
         label = _('Randomize Playlist')
 
-        if len(context['selected-items']) > 1:
+        if context['selection-count'] > 1:
             label = _('Randomize Selection')
 
         item = gtk.MenuItem(label)
@@ -245,6 +245,7 @@ class PlaylistContextMenu(menu.ProviderMenu):
     def get_context(self):
         context = common.LazyDict(self._parent)
         context['playlist'] = lambda name, parent: parent.playlist
+        context['selection-count'] = lambda name, parent: parent.get_selection_count()
         context['selected-paths'] = lambda name, parent: parent.get_selected_paths()
         context['selected-items'] = lambda name, parent: parent.get_selected_items()
         context['selected-tracks'] = lambda name, parent: parent.get_selected_tracks()
@@ -435,11 +436,23 @@ class PlaylistPage(NotebookPage):
         self.__show_toggle_menu(Playlist.shuffle_modes,
                 Playlist.shuffle_mode_names, self.on_shuffle_mode_set,
                 'shuffle_mode', widget, event)
+                
+    def on_shuffle_button_popup_menu(self, widget):
+        self.__show_toggle_menu(Playlist.shuffle_modes,
+                Playlist.shuffle_mode_names, self.on_shuffle_mode_set,
+                'shuffle_mode', widget, None)
+        return True
 
     def on_repeat_button_press_event(self, widget, event):
         self.__show_toggle_menu(Playlist.repeat_modes,
                 Playlist.repeat_mode_names, self.on_repeat_mode_set,
                 'repeat_mode', widget, event)
+                
+    def on_repeat_button_popup_menu(self, widget):
+        self.__show_toggle_menu(Playlist.repeat_modes,
+                Playlist.repeat_mode_names, self.on_repeat_mode_set,
+                'repeat_mode', widget, None)
+        return True
 
     def on_dynamic_button_toggled(self, widget):
         if widget.get_active():
@@ -485,25 +498,14 @@ class PlaylistPage(NotebookPage):
                 menu.append(gtk.SeparatorMenuItem())
             prev = item
         menu.show_all()
-        menu.popup(None, None, self._mode_menu_set_pos,
-                event.button, event.time, widget)
+        if event is not None:
+            menu.popup(None, None, guiutil.position_menu,
+                        event.button, event.time, (self.window, widget))
+        else:
+            menu.popup(None, None, guiutil.position_menu,
+                        0, 0, (self.window, widget))
         menu.reposition()
 
-    def _mode_menu_set_pos(self, menu, button):
-        """
-            Nicely position the shuffle/repeat popup menu with the
-            button's corner.
-        """
-        window_x, window_y = self.window.get_position()
-        button_allocation = button.get_allocation()
-        menu_allocation = menu.get_allocation()
-        position = (
-            window_x + button_allocation.x + 1,
-            window_y + button_allocation.y - menu_allocation.height - 1
-        )
-
-        return (position[0], position[1], True)
-
     def _mode_menu_set_toggle(self, menu, button, name):
         mode = getattr(self.playlist, name)
         self.on_mode_changed(None, None, mode, button)
@@ -592,6 +594,7 @@ class PlaylistView(AutoScrollTreeView, providers.ProviderHandler):
         self.button_pressed = False # used by columns to determine whether
                                     # a notify::width event was initiated
                                     # by the user.
+        self._insert_focusing = False
 
         self.set_fixed_height_mode(True) # MASSIVE speedup - don't disable this!
         self.set_rules_hint(True)
@@ -649,6 +652,14 @@ class PlaylistView(AutoScrollTreeView, providers.ProviderHandler):
             self.modelfilter.refilter()
             logger.debug("Filtering playlist '%s' by '%s' completed." % (self.playlist.name, filter_string))
         
+    def get_selection_count(self):
+        '''
+            Returns the number of items currently selected in the
+            playlist. Prefer this to len(get_selected_tracks()) et al
+            if you will discard the actual track list
+        '''
+        return self.get_selection().count_selected_rows()
+        
     def get_selected_tracks(self):
         """
             Returns a list of :class:`xl.trax.Track`
@@ -658,22 +669,36 @@ class PlaylistView(AutoScrollTreeView, providers.ProviderHandler):
 
     def get_selected_paths(self):
         """
-            Returns a list of pairs of treepaths
-            which are currently selected in the playlist.
+            Returns a list of pairs of treepaths which are currently
+            selected in the playlist.
+            
+            The treepaths are returned for the base model, so they are
+            indices that can be used with the playlist currently
+            associated with this view.
         """
         selection = self.get_selection()
         model, paths = selection.get_selected_rows()
+        
+        if isinstance(model, gtk.TreeModelFilter):
+            paths = [model.convert_path_to_child_path(path) for path in paths]
+        
         return paths
 
     def get_selected_items(self):
         """
             Returns a list of pairs of indices and :class:`xl.trax.Track`
             which are currently selected in the playlist.
+            
+            The indices can be used with the playlist currently associated
+            with this view.
         """
-        paths = self.get_selected_paths()
-        model = self.get_model()
+        selection = self.get_selection()
+        model, paths = selection.get_selected_rows()
         try:
-            tracks = [(path[0], model.get_value(model.get_iter(path), 0)) for path in paths]
+            if isinstance(model, gtk.TreeModelFilter):
+                tracks = [(model.convert_path_to_child_path(path)[0], model.get_value(model.get_iter(path), 0)) for path in paths]
+            else:
+                tracks = [(path[0], model.get_value(model.get_iter(path), 0)) for path in paths]
         except TypeError: #one of the paths was invalid
             return []
         return tracks
@@ -723,6 +748,7 @@ class PlaylistView(AutoScrollTreeView, providers.ProviderHandler):
         #self.model.columns = columns
         # TODO: What is the fixme talking about?
         self.model = PlaylistModel(self.playlist, columns, self.player)
+        self.model.connect('row-inserted', self.on_row_inserted)
         self.set_model(self.model)
         self._setup_filter()
 
@@ -825,6 +851,7 @@ class PlaylistView(AutoScrollTreeView, providers.ProviderHandler):
         
     def on_cursor_changed(self, widget):
         context = common.LazyDict(self)
+        context['selection-count'] = lambda name, parent: parent.get_selection_count()
         context['selected-items'] = lambda name, parent: parent.get_selected_items()
         context['selected-tracks'] = lambda name, parent: parent.get_selected_tracks()
         event.log_event( 'playlist_cursor_changed', self, context)
@@ -837,6 +864,19 @@ class PlaylistView(AutoScrollTreeView, providers.ProviderHandler):
             return
 
         self._play_track_at(position, track, True)
+        
+    def on_row_inserted(self, model, path, iter):
+        '''
+            When something is inserted into the playlist, focus on it. If 
+            there are multiple things inserted, focus only on the first. 
+        '''
+        def _set_cursor():
+            self.set_cursor(path)
+            self._insert_focusing = False
+            
+        if not self._insert_focusing:
+            self._insert_focusing = True
+            glib.idle_add(_set_cursor)
 
     def do_button_press_event(self, e):
         """
@@ -973,6 +1013,10 @@ class PlaylistView(AutoScrollTreeView, providers.ProviderHandler):
 
         if drop_info:
             path, position = drop_info
+            model = self.get_model()
+            if isinstance(model, gtk.TreeModelFilter):
+                path = model.convert_path_to_child_path(path)
+            
             insert_position = path[0]
             if position in (gtk.TREE_VIEW_DROP_AFTER, gtk.TREE_VIEW_DROP_INTO_OR_AFTER):
                 insert_position += 1
