@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -303,9 +303,8 @@ class RatingColumn(Column):
         if rating == oldrating:
             rating = 0
 
-        track.set_rating(rating)
-        maximum = settings.get_option('rating/maximum', 5)
-        event.log_event('rating_changed', self, rating / maximum * 100)
+        rating = track.set_rating(rating)
+        event.log_event('rating_changed', self, rating)
 providers.register('playlist-columns', RatingColumn)
 
 class DateColumn(Column):
